documentFactory.Z3950DocumentStream

|  | ## Cheshire3 Object Model: Class Z3950DocumentStream

Module documentFactory :: Class Z3950DocumentStream

## Class Z3950DocumentStream
source code

Object Tree:

    BaseDocumentStream --+
                         |
      RemoteDocumentStream --+
                             |
                            Z3950DocumentStream

Instance Methods

open_stream(self, stream)
find_documents(self, session, cache=0)
Inherited from `RemoteDocumentStream`: `parse_url` Inherited from `BaseDocumentStream`: `__init__`, `fetch_document`

Class Variables

Inherited from `BaseDocumentStream`: `codec`, `documents`, `factory`, `filterRe`, `format`, `length`, `locations`, `schema`, `stream`, `streamLocation`

Method Details

### open_stream(self, stream) | source code
Overrides: BaseDocumentStream.open_stream

### find_documents(self, session, cache=0) | source code